@@ -36,11 +36,7 @@ class PDF::Reader
     attr_reader :widths, :first_char, :last_char, :basefont, :font_descriptor,
                 :cid_widths, :cid_default_width
 
-    def initialize(ohash = nil, obj = nil)
-      if ohash.nil? || obj.nil?
-        $stderr.puts "DEPREACTION WARNING - PDF::Reader::Font.new should be called with 2 args"
-        return
-      end
+    def initialize(ohash, obj)
       @ohash = ohash
       @tounicode = nil
 
@@ -52,12 +48,6 @@ class PDF::Reader
       @encoding ||= PDF::Reader::Encoding.new(:StandardEncoding)
     end
 
-    def basefont=(font)
-      $stderr.puts "Font#basefont= is deprecated and will be removed in the 2.0 release"
-      @encoding ||= default_encoding(font)
-      @basefont = font
-    end
-
     def to_utf8(params)
       if @tounicode
         to_utf8_via_cmap(params)
@@ -161,15 +151,16 @@ class PDF::Reader
     end
 
     def to_utf8_via_cmap(params)
-      if params.class == Fixnum
+      case params
+      when Integer
         [
           @tounicode.decode(params) || PDF::Reader::Encoding::UNKNOWN_CHAR
         ].flatten.pack("U*")
-      elsif params.class == String
+      when String
         params.unpack(encoding.unpack).map { |c|
           @tounicode.decode(c) || PDF::Reader::Encoding::UNKNOWN_CHAR
         }.flatten.pack("U*")
-      elsif params.class == Array
+      when Array
         params.collect { |param| to_utf8_via_cmap(param) }
       else
         params
@@ -181,11 +172,12 @@ class PDF::Reader
         raise UnsupportedFeatureError, "font encoding '#{encoding}' currently unsupported"
       end
 
-      if params.class == Fixnum
+      case params
+      when Integer
         encoding.int_to_utf8_string(params)
-      elsif params.class == String
+      when String
         encoding.to_utf8(params)
-      elsif params.class == Array
+      when Array
         params.collect { |param| to_utf8_via_encoding(param) }
       else
         params
