@@ -36,7 +36,7 @@ module PDF
         @cache       = options[:cache] || {}
 
         unless @page_object.is_a?(::Hash)
-          raise ArgumentError, "invalid page: #{pagenum}"
+          raise InvalidPageError, "Invalid page: #{pagenum}"
         end
       end
 
@@ -155,7 +155,7 @@ module PDF
 
       # calls the name callback method on each receiver object with params as the arguments
       #
-      def callback (receivers, name, params=[])
+      def callback(receivers, name, params=[])
         receivers.each do |receiver|
           receiver.send(name, *params) if receiver.respond_to?(name)
         end
