@@ -2,7 +2,7 @@
 
 module EncodingHelper
   def binary_string(str)
-    str = str.force_encoding("binary") if str.respond_to?(:force_encoding)
+    str = str.force_encoding("binary")
     str
   end
 
@@ -10,8 +10,6 @@ module EncodingHelper
   # to ensure everything is UTF-8 encoded
   #
   def check_utf8(obj)
-    return unless RUBY_VERSION >= "1.9"
-
     case obj
     when Array
       obj.each { |item| check_utf8(item) }
@@ -32,15 +30,13 @@ module EncodingHelper
   # to ensure everything is Binary encoded
   #
   def check_binary(obj)
-    return unless RUBY_VERSION >= "1.9"
-
     case obj
     when Array
-      obj.each { |item| check_utf8(item) }
+      obj.each { |item| check_binary(item) }
     when Hash
       obj.each { |key, value|
-        check_utf8(key)
-        check_utf8(value)
+        check_binary(key)
+        check_binary(value)
       }
     when String
       expect(obj.encoding).to eq Encoding.find("binary")
